@@ -4,16 +4,11 @@
 #include <glib.h>
 #include <libgnome/gnome-i18n.h>
 
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <unistd.h>
-
 #include "gnome-settings-daemon.h"
 #include "gnome-settings-xsettings.h"
 #include "xsettings-manager.h"
 
-extern XSettingsManager *manager;
+extern XSettingsManager **managers;
 
 #ifdef HAVE_XFT2
 #define FONT_RENDER_DIR "/desktop/gnome/font_rendering"
@@ -44,31 +39,40 @@ static void
 translate_bool_int (TranslationEntry *trans,
 		    GConfValue       *value)
 {
+  int i;
+
   g_assert (value->type == trans->gconf_type);
   
-  xsettings_manager_set_int (manager, trans->xsetting_name,
-                             gconf_value_get_bool (value));
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_set_int (managers [i], trans->xsetting_name,
+                               gconf_value_get_bool (value));
 }
 
 static void
 translate_int_int (TranslationEntry *trans,
                    GConfValue       *value)
 {
+  int i;
+
   g_assert (value->type == trans->gconf_type);
-  
-  xsettings_manager_set_int (manager, trans->xsetting_name,
-                             gconf_value_get_int (value));
+
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_set_int (managers [i], trans->xsetting_name,
+                               gconf_value_get_int (value));
 }
 
 static void
 translate_string_string (TranslationEntry *trans,
                          GConfValue       *value)
 {
+  int i;
+
   g_assert (value->type == trans->gconf_type);
 
-  xsettings_manager_set_string (manager,
-                                trans->xsetting_name,
-                                gconf_value_get_string (value));
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_set_string (managers [i],
+                                  trans->xsetting_name,
+                                  gconf_value_get_string (value));
 }
 
 static TranslationEntry translations [] = {
@@ -159,7 +163,10 @@ process_value (TranslationEntry *trans,
 {  
   if (val == NULL)
     {
-      xsettings_manager_delete_setting (manager, trans->xsetting_name);
+      int i;
+
+      for (i = 0; managers [i]; i++)  
+        xsettings_manager_delete_setting (managers [i], trans->xsetting_name);
     }
   else
     {
@@ -181,14 +188,16 @@ static void
 xsettings_callback (GConfEntry *entry)
 {
   TranslationEntry *trans;
-  trans = find_translation_entry (entry->key);
+  int i;
 
+  trans = find_translation_entry (entry->key);
   if (trans == NULL)
     return;
 
   process_value (trans, entry->value);
   
-  xsettings_manager_notify (manager);
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_notify (managers [i]);
 }
 
 void
@@ -208,11 +217,14 @@ static void
 xft_callback (GConfEntry *entry)
 {
   GConfClient *client;
+  int i;
 
   client = gconf_client_get_default ();
 
   gnome_settings_update_xft (client);
-  xsettings_manager_notify (manager);
+
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_notify (managers [i]);
 }
 
 typedef struct
@@ -320,122 +332,14 @@ gnome_xft_settings_get (GConfClient      *client,
 static void
 gnome_xft_settings_set_xsettings (GnomeXftSettings *settings)
 {
-  xsettings_manager_set_int (manager, "Xft/Antialias", settings->antialias);
-  xsettings_manager_set_int (manager, "Xft/Hinting", settings->hinting);
-  xsettings_manager_set_string (manager, "Xft/HintStyle", settings->hintstyle);
-  xsettings_manager_set_int (manager, "Xft/DPI", settings->dpi);
-  xsettings_manager_set_string (manager, "Xft/RGBA", settings->rgba);
-}
-
-/*
- * Helper function for spawn_with_input() - write an entire
- * string to a fd.
- */
-static gboolean
-write_all (int         fd,
-	   const char *buf,
-	   gsize       to_write)
-{
-  while (to_write > 0)
+  int i;
+  for (i = 0; managers [i]; i++)  
     {
-      gssize count = write (fd, buf, to_write);
-      if (count < 0)
-	{
-	  if (errno != EINTR)
-	    return FALSE;
-	}
-      else
-	{
-	  to_write -= count;
-	  buf += count;
-	}
-    }
-
-  return TRUE;
-}
-
-/*
- * Helper function for spawn_with_input() - wait for a child
- * to exit.
- */
-gboolean
-wait_for_child (int  pid,
-		int *status)
-{
-  gint ret;
-
- again:
-  ret = waitpid (pid, status, 0);
-
-  if (ret < 0)
-    {
-      if (errno == EINTR)
-        goto again;
-      else
-        {
-	  g_warning ("Unexpected error in waitpid() (%s)",
-		     g_strerror (errno));
-	  return FALSE;
-        }
-    }
-
-  return TRUE;
-}
-
-/**
- * spawn_with_input:
- * @argv: command line to run
- * @input: string to write to the child process. 
- * 
- * Spawns a child process specified by @argv, writes the text in
- * @input to it, then waits for the child to exit. Any failures
- * are output through g_warning(); if you wanted to use this in
- * cases where errors need to be presented to the user, some
- * modification would be needed.
- **/
-static void
-spawn_with_input (char      **argv,
-		  const char *input)
-{
-  int exit_status;
-  int child_pid;
-  int inpipe;
-  GError *err = NULL;
-  
-  if (!g_spawn_async_with_pipes (NULL /* working directory */, argv, NULL /* envp */,
-				 G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
-				 NULL, NULL, /* child setup and data */
-				 &child_pid,
-				 &inpipe, NULL, NULL, /* stdin, stdout, stderr */
-				 &err))
-    {
-      gchar *command = g_strjoinv (" ", argv);
-      g_warning ("Could not execute %s: %s", command, err->message);
-      g_error_free (err);
-      g_free (command);
-
-      return;
-    }
-
-  if (input)
-    {
-      if (!write_all (inpipe, input, strlen (input)))
-	{
-	  gchar *command = g_strjoinv (" ", argv);
-	  g_warning ("Could not write input to %s", command);
-	  g_free (command);
-	}
-
-      close (inpipe);
-    }
-      
-  wait_for_child (child_pid, &exit_status);
-
-  if (!WIFEXITED (exit_status) || WEXITSTATUS (exit_status))
-    {
-      gchar *command = g_strjoinv (" ", argv);
-      g_warning ("Command %s failed", command);
-      g_free (command);
+      xsettings_manager_set_int (managers [i], "Xft/Antialias", settings->antialias);
+      xsettings_manager_set_int (managers [i], "Xft/Hinting", settings->hinting);
+      xsettings_manager_set_string (managers [i], "Xft/HintStyle", settings->hintstyle);
+      xsettings_manager_set_int (managers [i], "Xft/DPI", settings->dpi);
+      xsettings_manager_set_string (managers [i], "Xft/RGBA", settings->rgba);
     }
 }
 
@@ -456,7 +360,7 @@ gnome_xft_settings_set_xresources (GnomeXftSettings *settings)
   g_string_append_printf (add_string,
 			  "Xft.rgba: %s\n", settings->rgba);
 
-  spawn_with_input (add, add_string->str);
+  gnome_settings_daemon_spawn_with_input (add, add_string->str);
 
   g_string_free (add_string, TRUE);
 }
@@ -509,5 +413,6 @@ gnome_settings_xsettings_load (GConfClient *client)
   gnome_settings_update_xft (client);
 #endif /* HAVE_XFT */
 
-  xsettings_manager_notify (manager);
+  for (i = 0; managers [i]; i++)  
+    xsettings_manager_notify (managers [i]);
 }
