@@ -73,6 +73,7 @@ compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data
 {
 	GValue val_a = {0};
 	GValue val_b = {0};
+	gint cmp;
 	const gchar *str_a, *str_b;
 
 	gtk_tree_model_get_value (model, a, SORT_DATA_COLUMN, &val_a);
@@ -80,12 +81,17 @@ compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data
 	gtk_tree_model_get_value (model, b, SORT_DATA_COLUMN, &val_b);
 	str_b = g_value_get_string (&val_b);
 
+	cmp = g_ascii_strcasecmp (str_a, str_b);
+	
+	g_value_unset (&val_a);
+	g_value_unset (&val_b);
+	
 	if (!str_a)
 		return 1;
 	else if (!str_b)
 		return -1;
 	else
-		return g_ascii_strcasecmp (str_a, str_b);
+		return cmp;
 }
 
 static void
